@@ -288,7 +288,7 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 	marker = champlain_label_new_from_file ("icons/emblem-generic.png", NULL);
 	g_signal_connect(CHAMPLAIN_LOCATION(marker), "button-press", G_CALLBACK(marker_function), station);
 	marker = champlain_label_new_from_file ("icons/emblem-generic.png", NULL);
-	station = g_strdup("Dubai, Saudi Arabia\n<span size=\"small\">MBS FM</span>");
+	station = g_strdup("Dubai, Saudi Arabia\n<span size=\"small\">Middle East Broadcasting Center FM</span>");
 	champlain_label_set_text (CHAMPLAIN_LABEL (marker), station);
 	champlain_label_set_use_markup (CHAMPLAIN_LABEL (marker), TRUE);
 	champlain_label_set_color (CHAMPLAIN_LABEL (marker), &city_c_color);
